# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/projects/poject/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/projects/poject/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Projects\\Poject\\": "packages/projects/poject/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Projects\Poject\Providers\PojectServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Poject'  => Projects\Poject\Facades\Poject::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Projects\\PojectTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Projects\Poject\Providers\PojectServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Projects\Poject\Providers\PojectServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Projects\Poject\Providers\PojectServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/poject/{modulename}

**User**

    http://path-to-route-folder/user/poject/{modulename}

**Public**

    http://path-to-route-folder/pojects


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/poject/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/poject/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/poject/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/poject/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/poject/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/poject/{modulename}/{slug}
    METHOD: GET